==> haskell-test-framework-smallcheck-0.2-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-smallcheck
version: 0.2
id: test-framework-smallcheck-0.2-9WZnG8hPcZQ9k4kCuh4Kn3
key: test-framework-smallcheck-0.2-9WZnG8hPcZQ9k4kCuh4Kn3
license: BSD3
maintainer: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/smallcheck
synopsis: Support for SmallCheck tests in test-framework
description:
    Support for SmallCheck tests in test-framework
category: Testing
author: Roman Cheplyaka <roma@ro-che.info>
exposed: True
indefinite: False
exposed-modules:
    Test.Framework.Providers.SmallCheck
abi: 98416d840bc261ea21691dc7313595f7
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/test-framework-smallcheck-0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/test-framework-smallcheck-0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/test-framework-smallcheck-0.2
hs-libraries: HStest-framework-smallcheck-0.2-9WZnG8hPcZQ9k4kCuh4Kn3
depends:
    base-4.10.1.0 smallcheck-1.1.2-9sgfSIY97hc9eZoBXsyzEb
    test-framework-0.8.1.1-9AeLb617x2jBF4p0QVUN5W transformers-0.5.2.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             smallcheck-1.1.2-9sgfSIY97hc9eZoBXsyzEb=dd6db9950ffcefd0737ff4804620afa6
             test-framework-0.8.1.1-9AeLb617x2jBF4p0QVUN5W=b45e1022acfab6deb1dac5f0d480e45d
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-test-framework-smallcheck/html/test-framework-smallcheck.haddock
haddock-html: /usr/share/doc/haskell-test-framework-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-smallcheck-0.2-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-smallcheck
version: 0.2
id: test-framework-smallcheck-0.2-8e20LX335BDH3ypV8iFuUr
key: test-framework-smallcheck-0.2-8e20LX335BDH3ypV8iFuUr
license: BSD3
maintainer: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/smallcheck
synopsis: Support for SmallCheck tests in test-framework
description:
    Support for SmallCheck tests in test-framework
category: Testing
author: Roman Cheplyaka <roma@ro-che.info>
exposed: True
indefinite: False
exposed-modules:
    Test.Framework.Providers.SmallCheck
abi: 1786f66c79c0d19ded00a7367e2ca8ab
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/test-framework-smallcheck-0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/test-framework-smallcheck-0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/test-framework-smallcheck-0.2
hs-libraries: HStest-framework-smallcheck-0.2-8e20LX335BDH3ypV8iFuUr
depends:
    base-4.10.1.0 smallcheck-1.1.2-9sgfSIY97hc9eZoBXsyzEb
    test-framework-0.8.1.1-1j2D7D7TsB6Dk6k7Kv9vsS transformers-0.5.2.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             smallcheck-1.1.2-9sgfSIY97hc9eZoBXsyzEb=dd6db9950ffcefd0737ff4804620afa6
             test-framework-0.8.1.1-1j2D7D7TsB6Dk6k7Kv9vsS=61185a2abaab3538c468e070b14b2d69
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-test-framework-smallcheck/html/test-framework-smallcheck.haddock
haddock-html: /usr/share/doc/haskell-test-framework-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
